rnalysis.filtering.DESeqFilter
==============================

.. currentmodule:: rnalysis.filtering

.. autoclass:: DESeqFilter


   .. automethod:: __init__


   .. rubric:: Methods

   .. autosummary::
    :toctree:

      ~DESeqFilter.__init__
      ~DESeqFilter.biotypes
      ~DESeqFilter.describe
      ~DESeqFilter.difference
      ~DESeqFilter.filter_abs_log2_fold_change
      ~DESeqFilter.filter_biotype
      ~DESeqFilter.filter_by_ref_table_attr
      ~DESeqFilter.filter_fold_change_direction
      ~DESeqFilter.filter_percentile
      ~DESeqFilter.filter_significant
      ~DESeqFilter.filter_top_n
      ~DESeqFilter.head
      ~DESeqFilter.intersection
      ~DESeqFilter.number_filters
      ~DESeqFilter.print_features
      ~DESeqFilter.save_csv
      ~DESeqFilter.split_by_percentile
      ~DESeqFilter.split_by_ref_table_attr
      ~DESeqFilter.split_fold_change_direction
      ~DESeqFilter.symmetric_difference
      ~DESeqFilter.tail
      ~DESeqFilter.text_filters
      ~DESeqFilter.union
      ~DESeqFilter.volcano_plot





